//go:build windows

package cli

const (
	TerminalClearLine = "\r\r"
)
